#
# spec file for package python-autoray
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-autoray
Version:        0.6.3
Release:        1.2
Summary:        A lightweight python automatic-array library
License:        Apache-2.0
URL:            https://github.com/jcmgray/autoray
Source:         https://files.pythonhosted.org/packages/source/a/autoray/autoray-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module opt-einsum}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Write backend agnostic numeric code compatible with any numpy-ish array library.

%prep
%setup -q -n autoray-%{version}
sed -i -e '/addopts/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# flaky test (failed 2 out of 6 times on x86_64 during preparation for submit)
donttest="(test_linalg_solve and float32-numpy)"
# 32 bit not supported upstream: this one fails because it cannot cast int64 to int32 on 32-bit
[ $(getconf LONG_BIT) -eq 32 ] && donttest="$donttest or (test_take and numpy)"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/autoray
%{python_sitelib}/autoray-%{version}.dist-info

%changelog
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * `autoray.lazy.compute`: allow computing multiple outputs
    simultaneously
  * `autoray.lazy.Function` allow pickling and viewing of
    uncompiled source
  * make sure `shape` and `ndim` work for builtins similarly to
    `numpy.{shape,ndim}`
  * Add: `autoray.lazy.where` function for `LazyArray`
  * Add: `autoray.lazy.take` function for `LazyArray`
  * Add`LazyArray.plot_history_stats` pie charts
  * Add `autoray.shape` and `autoray.ndim` as preferred shape
    functions
  * Add basic support for `aesara`
  * `LazyArray`: fix negative axis reductions
  * fix fancy indexing of `LazyArray` objects
* Thu Jan 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  * autoray.lazy: Much better tools for inspecting the
    computational graph:
  - LazyArray.show()
  - LazyArray.plot_circuit()
  - LazyArray.plot_history_functions() and variants
  - LazyArray.history_fn_frequencies
  * Global submodule aliases:
  - enables e.g. dispatching do("scipy.linalg.lu", x:
    numpy.ndarray) and cupy.scipy to cupyx.scipy
  * Fix for complex and builtins and newer numpy (#11).
* Sat Jan 14 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.5.3
  * add lazy.diag
  * update infrastructure, including moving from versioneer to
    setuptools_scm
- Release 0.5.1
  * allow Composed.register to be used as a decorator
- Release 0.3.2
  * tweaks to compiler.py
- No relevant release or tag notes for other releases since 0.2.5
- PEP517 build
* Mon Jan 24 2022 Benjamin Greiner <code@bnavigator.de>
- SciPy and dask are optional
- Don't test dask with python310: not supported yet
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Update to version 0.2.5.
  * No changelog given.
- Skip python36 because numpy no longer support it.
* Wed Aug 19 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix source url to fetch from github
* Wed Aug 19 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove not stated dependencies
- Do not run coverage testing
* Tue Aug 18 2020 andy great <andythe_great@pm.me>
- Initial package release.
